from setuptools import setup

setup(
    name='abork-mailer',
    version='1.0.5', 
    packages=['mailer'], 
    package_dir={'mailer': 'src'},
    author='Alex Bork',
    description='Mailer Library'
    )